#!/usr/bin/env python3
# ------------------------------------------------------------------------------
# Copyright 2023 Open Text.
#
# The only warranties for products and services of Open Text and its
# affiliates and licensors (“Open Text”) are as may be set forth in the
# express warranty statements accompanying such products and services.
# Nothing herein should be construed as constituting an additional
# warranty. Open Text shall not be liable for technical or editorial
# errors or omissions contained herein. The information contained herein
# is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains
# confidential information and a valid license is required for possession,
# use or copying. If this work is provided to the U.S. Government,
# consistent with FAR 12.211 and 12.212, Commercial Computer Software,
# Computer Software Documentation, and Technical Data for Commercial Items
# are licensed to the U.S. Government under vendor's standard commercial
# license.
# ------------------------------------------------------------------------------

import os
import subprocess
import sys

def check_ldap_address_reachable(address):
    try:
        subprocess.check_output(['ping', '-c', '1', address], timeout=2)
        return True
    except subprocess.CalledProcessError:
        return False
    except subprocess.TimeoutExpired:
        return False

def fetch_ldap_servers(directory_path):
    try:
        items = os.listdir(directory_path)
        return items
    except OSError as e:
        return f"Error: {e}"
    
directory_path = '/etc/sysconfig/novell/ldap_servers/'
ldap_addresses = fetch_ldap_servers(directory_path)
ldap_addresses = list(ldap_addresses)

if 'ldap_server.template' in ldap_addresses:
    ldap_addresses.remove('ldap_server.template')

unreachable_ldap_address = [address for address in ldap_addresses if not check_ldap_address_reachable(address)]

print(unreachable_ldap_address)

if len(unreachable_ldap_address) == 0:
    sys.exit(0)
else:
    sys.exit(1)